# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023Protocol(str, Enum):
    """
    Enum class for NSB2023Protocol.
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    N_2119__TRAINING_AND_QUAL = '2119 - Training and qualification of animal users'
    N_2201__INTERROGATING_PRO = '2201 - Interrogating projections and gene '
    N_2202__TESTING_AA_VS_IN = '2202 - Testing AAVs in Parkinson\'s mouse models'
    N_2204__PRIMARY_NEURON_AN = '2204 - Primary neuron and brain slice '
    N_2205__OPTIMIZATION_AND = '2205 - Optimization and validation of viral vectors'
    N_2207__IN__VITRO__BRAIN = '2207 - In Vitro Brain Stimulation'
    N_2212__INVESTIGATING__BR = '2212 - Investigating Brain States'
    N_2301__TESTING_OF_ENHANC = '2301 - Testing of enhancers and AAV gene therapy vectors'
    N_2304__NEUROSURGERY__BEH = '2304 - Neurosurgery & Behavior Training Protocol'
    N_2305__IN__VIVO__BRAIN = '2305 - In Vivo Brain Stimulation'
    N_2306__PATCH_SEQ_CHARACT = '2306 - Patch-seq characterization of mouse neurons in acute brain slices for cross-species comparison studies'
    N_2307__DISSECTING_THE_NE = '2307 - Dissecting the neural circuits of adaptive control of behavior'
    N_2308__INDUCTION_OF__IMM = '2308 - Induction of Immune Memory'
    N_2401__THE_USE_OF_MICE_F = '2401 - The use of mice for the development of biological recorders'
    N_2402__BRAIN__OBSERVATOR = '2402 - Brain Observatory Optical Physiology'
    N_2403__ELECTROPHYSIOLOGY = '2403 - Electrophysiology Mindscope Phase 4'
    N_2405__ANALYSIS_OF__INTE = '2405 - Analysis of Integrated Neuronal Phenotypes'
    N_2406__CHARACTERIZATION = '2406 - Characterization of mouse and viral genetic tools'
    N_2410__VALIDATION_OF_BRA = '2410 - Validation of brain cell type enhancer AAV vectors in rats'
    N_2412__CIRCUIT_TRACING_A = '2412 - Circuit tracing and optical physiology of mouse cortex'
    N_2413__NEUROPHYSIOLOGY_O = '2413 - Neurophysiology of Naturalistic Learning'
    N_2414__ELECTROPHYSIOLOGI = '2414 - Electrophysiological and optical interrogation of brain-wide neural circuits in the mouse'
    N_2415__OPTOPHYSIOLOGICAL = '2415 - Optophysiological analysis of brain-wide neural circuits in the mouse'
    N_2416__ANATOMICAL_ANALYS = '2416 - Anatomical analysis of brain-wide neural circuits in the mouse'
    N_2417__CHARACTERIZATION = '2417 - Characterization of transcriptomic cell type activation and their molecular adaptations that occur during psychedelic, antidepressants, and antipsychotic drug use'
    N_2418__IN__VITRO__SINGLE = '2418 - In Vitro Single Cell Characterization'
    N_2427__OPEN_SCOPE__MINDS = '2427 - OpenScope Mindscope animal protocol for Optical Physiology and Neuropixel'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023Protocol from a JSON string"""
        return cls(json.loads(json_str))


