# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from aind_sharepoint_service_async_client.models.nsb2023_list import NSB2023List

class TestNSB2023List(unittest.TestCase):
    """NSB2023List unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NSB2023List:
        """Test NSB2023List
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NSB2023List`
        """
        model = NSB2023List()
        if include_optional:
            return NSB2023List(
                age_x0020_at_x0020_injection = '',
                aind_x0020_project_x0020_name = 'Brain Wide Circuit Dynamics',
                ap2nd_inj = 1.337,
                app_author = 56,
                app_editor = '',
                attachments = True,
                author = '',
                author_id = 56,
                author_lookup_id = 56,
                editor_id = 56,
                editor_lookup_id = 56,
                test1_lookup_id = 56,
                test_x0020_1st_x0020_round_x0020_lookup_id = 56,
                behavior = 'No',
                behavior_x0020_autotrain_x0020_c = 'Coupled Baiting',
                behavior_x0020_complete = '',
                behavior_x0020_curriculum_x0020_ = '2.3',
                behavior_x0020_destination = 'Ephys',
                behavior_x0020_fiber_x0020_photo = 'Yes',
                behavior_x0020_first_x0020_video = '1.1',
                behavior_x0020_first_x0020_fip_x = '1.1',
                behavior_x0020_platform = 'Mindscope',
                behavior_x0020_type = 'Select...',
                behavior_x0020_fip_x0020_mode = 'N/A',
                black_x0020_cement = 'Yes',
                breg2_lamb = 1.337,
                burr1_x0020_injection_x0020_devi = 'Select...',
                burr1_x0020_perform_x0020_during = 'Initial Surgery',
                burr1_x0020_virus_x0020_biosafte = 'Select...',
                burr2_x0020_injection_x0020_devi = 'Select...',
                burr2_x0020_perform_x0020_during = 'Initial Surgery',
                burr2_x0020_status = 'Complete',
                burr2_x0020_virus_x0020_biosafte = 'Select...',
                burr3_x0020_injection_x0020_devi = 'Select...',
                burr3_x0020_perform_x0020_during = 'Initial Surgery',
                burr3_x0020_status = 'Complete',
                burr3_x0020_virus_x0020_biosafet = 'Select...',
                burr3_x0020_a_x002f_p = 1.337,
                burr3_x0020_d_x002f_v = 1.337,
                burr3_x0020_m_x002f_l = 1.337,
                burr4_x0020_injection_x0020_devi = 'Select...',
                burr4_x0020_perform_x0020_during = 'Initial Surgery',
                burr4_x0020_status = 'Complete',
                burr4_x0020_virus_x0020_biosafte = 'Select...',
                burr4_x0020_a_x002f_p = 1.337,
                burr4_x0020_d_x002f_v = 1.337,
                burr4_x0020_m_x002f_l = 1.337,
                burr5_x0020_injection_x0020_devi = 'Select...',
                burr5_x0020_perform_x0020_during = 'Initial Surgery',
                burr5_x0020_status = 'Complete',
                burr5_x0020_virus_x0020_biosafte = 'Select...',
                burr6_x0020_injection_x0020_devi = 'Select...',
                burr6_x0020_perform_x0020_during = 'Initial Surgery',
                burr6_x0020_status = 'Complete',
                burr6_x0020_virus_x0020_biosafte = 'Select...',
                burr_x0020_1_x0020_fiber_x0020_t = 'Standard (provided by NSB)',
                burr_x0020_1_x0020_grid_x0020_sp = 1.337,
                burr_x0020_1_x0020_injectable_x00 = '',
                burr_x0020_1_x0020_injectable_x01 = '',
                burr_x0020_1_x0020_injectable_x02 = '',
                burr_x0020_1_x0020_injectable_x03 = '',
                burr_x0020_1_x0020_injectable_x04 = '',
                burr_x0020_1_x0020_injectable_x05 = '',
                burr_x0020_1_x0020_injectable_x06 = '',
                burr_x0020_1_x0020_injectable_x0 = '',
                burr_x0020_1_x0020_intended_x002 = [
                    'Select...'
                    ],
                burr_x0020_1_x0020_spinal_x0020_ = 'Select...',
                burr_x0020_1_x0020_d_x002f_v_x00 = 1.337,
                burr_x0020_1_x0020_dv_x0020_2 = 1.337,
                burr_x0020_1_x0020_intended_x0020 = 'N/A',
                burr_x0020_1_x0020_intended_x0021 = 'N/A',
                burr_x0020_1_x0020_intended_x0022 = 'N/A',
                burr_x0020_1_x0020_intended_x0023 = 'N/A',
                burr_x0020_2_x0020_fiber_x0020_t = 'Standard (Provided by NSB)',
                burr_x0020_2_x0020_injectable_x00 = '',
                burr_x0020_2_x0020_injectable_x01 = '',
                burr_x0020_2_x0020_injectable_x02 = '',
                burr_x0020_2_x0020_injectable_x03 = '',
                burr_x0020_2_x0020_injectable_x04 = '',
                burr_x0020_2_x0020_injectable_x05 = '',
                burr_x0020_2_x0020_injectable_x06 = '',
                burr_x0020_2_x0020_injectable_x0 = '',
                burr_x0020_2_x0020_intended_x002 = [
                    'Select...'
                    ],
                burr_x0020_2_x0020_spinal_x0020_ = 'Select...',
                burr_x0020_2_x0020_d_x002f_v_x000 = 1.337,
                burr_x0020_2_x0020_d_x002f_v_x00 = 1.337,
                burr_x0020_2_x0020_intended_x0020 = 'N/A',
                burr_x0020_2_x0020_intended_x0021 = 'N/A',
                burr_x0020_2_x0020_intended_x0022 = 'N/A',
                burr_x0020_2_x0020_intended_x0023 = 'N/A',
                burr_x0020_3_x0020_angle = 1.337,
                burr_x0020_3_x0020_fiber_x0020_t = 'Standard (Provided by NSB)',
                burr_x0020_3_x0020_hemisphere = 'Select...',
                burr_x0020_3_x0020_injectable_x00 = '',
                burr_x0020_3_x0020_injectable_x01 = '',
                burr_x0020_3_x0020_injectable_x02 = '',
                burr_x0020_3_x0020_injectable_x03 = '',
                burr_x0020_3_x0020_injectable_x04 = '',
                burr_x0020_3_x0020_injectable_x05 = '',
                burr_x0020_3_x0020_injectable_x06 = '',
                burr_x0020_3_x0020_injectable_x0 = '',
                burr_x0020_3_x0020_intended_x002 = [
                    'Select...'
                    ],
                burr_x0020_3_x0020_d_x002f_v_x000 = 1.337,
                burr_x0020_3_x0020_d_x002f_v_x00 = 1.337,
                burr_x0020_3_x0020_intended_x0020 = 'N/A',
                burr_x0020_3_x0020_intended_x0021 = 'N/A',
                burr_x0020_3_x0020_intended_x0022 = 'N/A',
                burr_x0020_3_x0020_intended_x0023 = 'N/A',
                burr_x0020_4_x0020_angle = 1.337,
                burr_x0020_4_x0020_fiber_x0020_t = 'Standard (Provided by NSB)',
                burr_x0020_4_x0020_hemisphere = 'Select...',
                burr_x0020_4_x0020_injectable_x00 = '',
                burr_x0020_4_x0020_injectable_x01 = '',
                burr_x0020_4_x0020_injectable_x02 = '',
                burr_x0020_4_x0020_injectable_x03 = '',
                burr_x0020_4_x0020_injectable_x04 = '',
                burr_x0020_4_x0020_injectable_x05 = '',
                burr_x0020_4_x0020_injectable_x06 = '',
                burr_x0020_4_x0020_injectable_x0 = '',
                burr_x0020_4_x0020_intended_x002 = [
                    'Select...'
                    ],
                burr_x0020_4_x0020_d_x002f_v_x000 = 1.337,
                burr_x0020_4_x0020_d_x002f_v_x00 = 1.337,
                burr_x0020_4_x0020_intended_x0020 = 'N/A',
                burr_x0020_4_x0020_intended_x0021 = 'N/A',
                burr_x0020_4_x0020_intended_x0022 = 'N/A',
                burr_x0020_4_x0020_intended_x0023 = 'N/A',
                burr_x0020_5_x0020_angle = 1.337,
                burr_x0020_5_x0020_fiber_x0020_t = 'Standard (provided by NSB)',
                burr_x0020_5_x0020_hemisphere = 'Select...',
                burr_x0020_5_x0020_injectable_x00 = '',
                burr_x0020_5_x0020_injectable_x01 = '',
                burr_x0020_5_x0020_injectable_x02 = '',
                burr_x0020_5_x0020_injectable_x03 = '',
                burr_x0020_5_x0020_injectable_x04 = '',
                burr_x0020_5_x0020_injectable_x05 = '',
                burr_x0020_5_x0020_injectable_x06 = '',
                burr_x0020_5_x0020_injectable_x0 = '',
                burr_x0020_5_x0020_intended_x002 = [
                    'Select...'
                    ],
                burr_x0020_5_x0020_a_x002f_p = 1.337,
                burr_x0020_5_x0020_d_x002f_v_x000 = 1.337,
                burr_x0020_5_x0020_d_x002f_v_x001 = 1.337,
                burr_x0020_5_x0020_d_x002f_v_x00 = 1.337,
                burr_x0020_5_x0020_intended_x0020 = 'N/A',
                burr_x0020_5_x0020_intended_x0021 = 'N/A',
                burr_x0020_5_x0020_intended_x0022 = 'N/A',
                burr_x0020_5_x0020_intended_x0023 = 'N/A',
                burr_x0020_5_x0020_m_x002f_l = 1.337,
                burr_x0020_6_x0020_angle = 1.337,
                burr_x0020_6_x0020_fiber_x0020_t = 'Standard (provided by NSB)',
                burr_x0020_6_x0020_hemisphere = 'Select...',
                burr_x0020_6_x0020_injectable_x00 = '',
                burr_x0020_6_x0020_injectable_x01 = '',
                burr_x0020_6_x0020_injectable_x02 = '',
                burr_x0020_6_x0020_injectable_x03 = '',
                burr_x0020_6_x0020_injectable_x04 = '',
                burr_x0020_6_x0020_injectable_x05 = '',
                burr_x0020_6_x0020_injectable_x06 = '',
                burr_x0020_6_x0020_injectable_x0 = '',
                burr_x0020_6_x0020_intended_x002 = [
                    'Select...'
                    ],
                burr_x0020_6_x0020_a_x002f_p = 1.337,
                burr_x0020_6_x0020_d_x002f_v_x000 = 1.337,
                burr_x0020_6_x0020_d_x002f_v_x001 = 1.337,
                burr_x0020_6_x0020_d_x002f_v_x00 = 1.337,
                burr_x0020_6_x0020_intended_x0020 = 'N/A',
                burr_x0020_6_x0020_intended_x0021 = 'N/A',
                burr_x0020_6_x0020_intended_x0022 = 'N/A',
                burr_x0020_6_x0020_intended_x0023 = 'N/A',
                burr_x0020_6_x0020_m_x002f_l = 1.337,
                burr_x0020_hole_x0020_1_x0020_st = 'Complete',
                burr_x0020_hole_x0020_1 = 'Select...',
                burr_x0020_hole_x0020_2 = 'Select...',
                burr_x0020_hole_x0020_3 = 'Select...',
                burr_x0020_hole_x0020_4 = 'Select...',
                burr_x0020_hole_x0020_5 = 'Select...',
                burr_x0020_hole_x0020_6 = 'Select...',
                care_x0020_moduele = 'Select...',
                color_tag = '',
                com_coplanar = 'Select...',
                com_sinusbleed = 'Select...',
                com_swelling = 'Select...',
                compliance_asset_id = '',
                content_type = '',
                contusion = 'Select...',
                craniotomy_x0020_perform_x0020_d = 'Follow up Surgery',
                craniotomy_type = 'Select...',
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                date1st_injection = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                date_x0020_of_x0020_birth = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                date_x0020_of_x0020_surgery = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                date_range_start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                doc_icon = '',
                dv2nd_inj = 1.337,
                edit = '',
                editor = '',
                fiber_x0020_implant1_x0020_lengt = 'Select...',
                fiber_x0020_implant2_x0020_lengt = 'Select...',
                fiber_x0020_implant3_x0020_lengt = 'Select...',
                fiber_x0020_implant3_x0020_d_x00 = 1.337,
                fiber_x0020_implant4_x0020_lengt = 'Select...',
                fiber_x0020_implant4_x0020_d_x00 = 1.337,
                fiber_x0020_implant5_x0020_lengt = 'Select...',
                fiber_x0020_implant5_x0020_d_x00 = 1.337,
                fiber_x0020_implant6_x0020_lengt = 'Select...',
                fiber_x0020_implant6_x0020_d_x00 = 1.337,
                fiber_implant1_dv = 1.337,
                fiber_implant2_dv = 1.337,
                first_inj_recovery = 1.337,
                first_injection_iso_duration = 1.337,
                first_injection_weight_after = 1.337,
                first_injection_weight_befor = 1.337,
                folder_child_count = '',
                headpost = 'Select...',
                headpost_x0020_perform_x0020_dur = 'Follow up Surgery',
                headpost_type = 'Select...',
                hemisphere2nd_inj = 'Select...',
                hp_iso_level = 1.337,
                hp_recovery = 1.337,
                hp_surgeon_comments = '',
                hp_work_station = 'Select...',
                iacuc_x0020_protocol_x0020__x002 = 'Select...',
                id = 1.337,
                implant_id_coverslip_type = 'Select...',
                inj1_alternating_time = '',
                inj1_angle_v2 = 1.337,
                inj1_current = '',
                inj1_ionto_time = '',
                inj1_storage_location = '',
                inj1_type = 'Select...',
                inj1_virus_strain_rt = '',
                inj1volperdepth = 1.337,
                inj2_alternating_time = '',
                inj2_angle_v2 = 1.337,
                inj2_current = '',
                inj2_ionto_time = '',
                inj2_storage_location = '',
                inj2_type = 'Select...',
                inj2_virus_strain_rt = '',
                inj2volperdepth = 1.337,
                inj3_alternating_time = '',
                inj3_current = '',
                inj3_ionto_time = '',
                inj3_storage_location = '',
                inj3_type = 'Select...',
                inj3ret_setting = 'Off',
                inj3volperdepth = 1.337,
                inj4_alternating_time = '',
                inj4_current = '',
                inj4_ionto_time = '',
                inj4_storage_location = '',
                inj4_type = 'Select...',
                inj4_virus_strain_rt = '',
                inj4ret_setting = 'Off',
                inj4volperdepth = 1.337,
                inj5_alternating_time = '',
                inj5_current = '',
                inj5_ionto_time = '',
                inj5_storage_location = '',
                inj5_type = 'Select...',
                inj5_virus_strain_rt = '',
                inj5ret_setting = 'Off',
                inj5volperdepth = 1.337,
                inj6_alternating_time = '',
                inj6_current = '',
                inj6_ionto_time = '',
                inj6_storage_location = '',
                inj6_type = 'Select...',
                inj6_virus_strain_rt = '',
                inj6ret_setting = 'Off',
                inj6volperdepth = 1.337,
                inj_virus_strain_rt = '',
                ionto_number_inj1 = 'Select...',
                ionto_number_inj2 = 'Select...',
                is_record = '',
                iso_x0020_on = 1.337,
                item_child_count = '',
                lab_tracks_x0020_group = '',
                lab_tracks_x0020_requestor = '',
                lab_tracks_x0020_id1 = '',
                lims_x0020_required = 'Select...',
                light_cycle = 'Standard Light Cycle (6am to 8pm light)',
                lims_project = '0200',
                lims_taskflow = 'AIND Ephys (Surgery only)',
                link_title = '',
                link_title_no_menu = '',
                long_requestor_comments = '',
                ml2nd_inj = 1.337,
                modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                nanoject_number_inj10 = 'Select...',
                nanoject_number_inj2 = 'Select...',
                non_x002d_nsb_x0020_surgeon = True,
                x0023__x0020_of_x0020_burr_x002 = 'Select...',
                pedigree_name = '',
                pi = '',
                procedure = 'Select...',
                procedure_x0020_family = 'Select...',
                procedure_x0020_slots = 'Select...',
                procedure_x0020_t2 = 'Select...',
                project_id = '101-03-001-10 Costa PGA Lab Research (Direct)',
                protocol = 'Select...',
                ret_setting0 = 'Off',
                ret_setting1 = 'Off',
                round1_inj_isolevel = 1.337,
                sex = 'Select...',
                surgery_status = 'Injection Pending',
                test1 = '',
                test_x0020_1st_x0020_round_x0020 = '',
                thermistor = 'No',
                title = '',
                ui_version_string = '',
                virus_x0020_hemisphere = 'Select...',
                virus_x0020_a_x002f_p = 1.337,
                virus_x0020_d_x002f_v = 1.337,
                virus_x0020_m_x002f_l = 1.337,
                weight_x0020_after_x0020_surgery = 1.337,
                weight_x0020_before_x0020_surger = 1.337,
                work_station1st_injection = 'Select...'
            )
        else:
            return NSB2023List(
        )
        """

    def testNSB2023List(self):
        """Test NSB2023List"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
