# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LASTcprep(str, Enum):
    """
    Enum class for TCPrep.
    """

    """
    allowed enum values
    """
    FRESH_BRAIN_DISSECTION = 'Fresh Brain Dissection (SOP AF0061)'
    MOUSE_CARDIAC_PERFUSION = 'Mouse Cardiac Perfusion (SOP AF0075)'
    ACSF_PERFUSION = 'ACSF Perfusion'
    MOUSE_BRAIN_PERFUSION_A = 'Mouse Brain Perfusion and Flash Freezing Protocol (SOP AF0138)'
    EMBRYO_COLLECTION = 'Embryo Collection'
    MOUSE_CARDIAC_PERFUSION_2 = 'Mouse Cardiac Perfusion and Brain Hemisphere Processing for Viral Genetic Tools Pipeline (SOP AF0140)'
    MOUSE_CARDIAC_PERFUSION_3 = 'Mouse Cardiac Perfusion with Gel'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LASTcprep from a JSON string"""
        return cls(json.loads(json_str))


