# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2019Issue(str, Enum):
    """
    Enum class for Issue
    """

    """
    allowed enum values
    """
    EXUDATE = 'Exudate'
    EYE_ISSUE = 'Eye Issue'
    METABOND = 'Metabond'
    MULTIPLE_ISSUES_NOTES_IN = 'Multiple Issues (Notes In comments)'
    NON_SURGICAL_ISSUE = 'Non-Surgical Issue'
    OTHERWRITE_IN_COMMENTS = 'Other..(write in comments)'
    REPLACEMENT_COVERSLIP = 'Replacement: Coverslip'
    REPLACEMENT_KWIKCAST = 'Replacement: Kwikcast'
    REPLACEMENT_ORING = 'Replacement: O-ring'
    SCABBING = 'Scabbing'
    SELECT = 'Select...'
    Z_MOTION = 'Z-Motion'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2019Issue from a JSON string"""
        return cls(json.loads(json_str))


