# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023Well(str, Enum):
    """
    Enum class for NSB2023Well.
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    NO_WELL = 'No Well'
    SCIENTIFICA_CAM = 'Scientifica (CAM)'
    MESOSCOPE = 'Mesoscope'
    NEUROPIXEL = 'Neuropixel'
    WHC_2_P = 'WHC 2P'
    WHC_NP = 'WHC NP'
    WHC_NP_ZIRCONIA = 'WHC NP (Zirconia)'
    AI_STRAIGHT_BAR_WELL = 'AI Straight bar well'
    LC_WELL = 'LC well'
    DHC_WELL = 'DHC well'
    MOTOR__CTX_SLAP2_WELL = 'Motor Ctx SLAP2 well'
    VISUAL__CTX_SLAP2_WELL = 'Visual Ctx SLAP2 well'
    OTHER_SEE_REQUESTOR_COMM = 'Other (See requestor comments)'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023Well from a JSON string"""
        return cls(json.loads(json_str))


