# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LASReqpro4(str, Enum):
    """
    Enum class for ReqPro4.
    """

    """
    allowed enum values
    """
    TISSUE_COLLECTION = 'Tissue Collection'
    INDUCTION = 'Induction'
    DOSING = 'Dosing'
    RETRO_ORBITAL_INJECTION = 'Retro-Orbital Injection'
    INTRACEREBROVENTRICULAR = 'Intracerebroventricular Injection'
    BLOOD_COLLECTION = 'Blood Collection'
    CEREBROSPINAL_FLUID_COL = 'Cerebrospinal Fluid Collection (CSF)'
    OTHER = 'Other'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LASReqpro4 from a JSON string"""
        return cls(json.loads(json_str))


