# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2019HpIsoLevel(str, Enum):
    """
    Enum class for HpIsoLevel
    """

    """
    allowed enum values
    """
    N_025 = '0.25'
    N_050 = '0.50'
    N_075 = '0.75'
    N_100 = '1.00'
    N_125 = '1.25'
    N_15 = '1.5'
    N_175 = '1.75'
    N_200 = '2.00'
    N_225 = '2.25'
    N_250 = '2.50'
    N_275 = '2.75'
    N_300 = '3.00+'
    SELECT = 'Select...'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2019HpIsoLevel from a JSON string"""
        return cls(json.loads(json_str))


