# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LASTctiss(str, Enum):
    """
    Enum class for TCTiss.
    """

    """
    allowed enum values
    """
    BRAIN = 'Brain'
    RIGHT_EYE = 'Right Eye'
    LEFT_EYE = 'Left Eye'
    EARS = 'Ears'
    SPINAL_CORD = 'Spinal Cord'
    HEART = 'Heart'
    LIVER = 'Liver'
    EMBRYO_SPECIFY_BELOW = 'Embryo (Specify below)'
    LYMPH_NODES_SPECIFY_BELO = 'Lymph nodes (Specify below)'
    SPLEEN = 'Spleen'
    KIDNEYS = 'Kidneys'
    REPRODUCTIVE_ORGAN = 'Reproductive Organ'
    EPIDIDYMIS = 'Epididymis'
    TAIL_SNIPS = 'Tail Snips'
    OTHER_TISSUE_SPECIFY_BE = 'Other Tissue (Specify below)'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LASTctiss from a JSON string"""
        return cls(json.loads(json_str))


