# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LASDeliverylocation(str, Enum):
    """
    Enum class for DeliveryLocation.
    """

    """
    allowed enum values
    """
    N_156_4C = '156 4c'
    N_139_80 = '139 -80'
    N_220_4C_IM = '220 4c(IM)'
    N_270_4C = '270 4c'
    N_270_80_B_SHELF_3_LEFT = '270 -80B Shelf 3 (Left)'
    N_320_AIND_4C = '320 AIND 4c'
    N_320_80_SHELF_6 = '320 -80 Shelf 6'
    N_340_4C = '340 4c'
    N_340_80_B_SHELF_1 = '340 -80B Shelf 1'
    N_370_WALK_IN_4C = '370 Walk-in 4c'
    N_379_20_A_SHELF_2 = '379 -20A Shelf 2'
    N_373_80_A_SHELF_2 = '373 -80A Shelf 2'
    N_420_4C = '420 4c'
    N_440_4C = '440 4c'
    N_470_4C = '470 4c'
    N_473_80_E_SHELF_3 = '473 -80E Shelf 3'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LASDeliverylocation from a JSON string"""
        return cls(json.loads(json_str))


