# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023Burr2SpinalLocation(str, Enum):
    """
    Enum class for Burr 2 Spinal Location.
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    BETWEEN_C1_C2 = 'Between C1-C2'
    BETWEEN_C2_C3 = 'Between C2-C3'
    BETWEEN_C3_C4 = 'Between C3-C4'
    BETWEEN_C4_C5 = 'Between C4-C5'
    BETWEEN_C6_C7 = 'Between C6-C7'
    BETWEEN_C7_C8 = 'Between C7-C8'
    BETWEEN_C8_T1 = 'Between C8-T1'
    BETWEEN_T1_T2 = 'Between T1-T2'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023Burr2SpinalLocation from a JSON string"""
        return cls(json.loads(json_str))


