# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023BehaviorAutotrainCurriculum(str, Enum):
    """
    Enum class for NSB2023Behavior Autotrain Curriculum.
    """

    """
    allowed enum values
    """
    COUPLED__BAITING = 'Coupled Baiting'
    UNCOUPLED__BAITING = 'Uncoupled Baiting'
    UNCOUPLED__WITHOUT__BAITI = 'Uncoupled Without Baiting'
    N_A = 'N/A'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023BehaviorAutotrainCurriculum from a JSON string"""
        return cls(json.loads(json_str))


