# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from aind_sharepoint_service_async_client.api.default_api import DefaultApi


class TestDefaultApi(unittest.IsolatedAsyncioTestCase):
    """DefaultApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = DefaultApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_get_las2020(self) -> None:
        """Test case for get_las2020

        Get Las 2020
        """
        pass

    async def test_get_nsb2019(self) -> None:
        """Test case for get_nsb2019

        Get Nsb 2019
        """
        pass

    async def test_get_nsb2023(self) -> None:
        """Test case for get_nsb2023

        Get Nsb 2023
        """
        pass

    async def test_get_nsb_present(self) -> None:
        """Test case for get_nsb_present

        Get Nsb Present
        """
        pass


if __name__ == '__main__':
    unittest.main()
