# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023Burr2InjectionDevice(str, Enum):
    """
    Enum class for Burr2 Injection Device.
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    NANO_1 = 'Nano #1'
    IONTO_1 = 'Ionto #1'
    NANO_2 = 'Nano #2'
    IONTO_2 = 'Ionto #2'
    NANO_3 = 'Nano #3'
    IONTO_3 = 'Ionto #3'
    NANO_4 = 'Nano #4'
    IONTO_4 = 'Ionto #4'
    NANO_5 = 'Nano #5'
    IONTO_5 = 'Ionto #5'
    NANO_6 = 'Nano #6'
    IONTO_6 = 'Ionto #6'
    NANO_7 = 'Nano #7'
    IONTO_7 = 'Ionto #7'
    NANO_8 = 'Nano #8'
    IONTO_8 = 'Ionto #8'
    NANO_9 = 'Nano #9'
    IONTO_9 = 'Ionto #9'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023Burr2InjectionDevice from a JSON string"""
        return cls(json.loads(json_str))


