# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from aind_sharepoint_service_async_client.models.las_rolims import LASRolims

class TestLASRolims(unittest.TestCase):
    """LASRolims unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testLASRolims(self):
        """Test LASRolims"""
        # inst = LASRolims()

if __name__ == '__main__':
    unittest.main()
