# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2019Procedure(str, Enum):
    """
    Enum class for Procedure
    """

    """
    allowed enum values
    """
    CUSTOM = 'Custom'
    HPC_CAM = 'HP+C CAM'
    HPC_MULTISCOPE = 'HP+C Multiscope'
    HPC_NEUROPIXEL_STYLE = 'HP+C Neuropixel style'
    HPINJ = 'HP+INJ'
    HP_INJECTION_OPTIC_FIBER = 'HP+Injection+Optic Fiber Implant'
    HP_ONLY = 'HP only'
    HP_TRANSCRANIAL_FOR_ISI = 'HP Transcranial (for ISI)'
    INJHPC = 'INJ+HP+C'
    INJWHC_NP = 'INJ+WHC NP'
    SELECT = 'Select...'
    STEREOTAXIC_INJECTION = 'Stereotaxic Injection'
    TRAINING_SURGERY = 'Training Surgery'
    WHC_NP = 'WHC NP'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2019Procedure from a JSON string"""
        return cls(json.loads(json_str))


