# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LASProjectid(str, Enum):
    """
    Enum class for ProjectID.
    """

    """
    allowed enum values
    """
    N_101_03_001_10_COSTA_PG = '101-03-001-10 Costa PGA Lab Research (Direct)'
    N_102_01_007_10_CTY_M_FIS = '102-01-007-10 CTY mFISH'
    N_102_01_009_10_CTY_MORP = '102-01-009-10 CTY Morphology'
    N_102_01_011_10_CTY_CONN = '102-01-011-10 CTY Connectome EM'
    N_102_01_012_10_CTY_CONN = '102-01-012-10 CTY Connectome Meso'
    N_102_01_016_10_CTY_TAXO = '102-01-016-10 CTY Taxonomy'
    N_102_01_029_20_CTY_BRAIN = '102-01-029-20 CTY BRAIN Cell-type Specific Enhancer Viruses'
    N_102_01_031_20_W4_CTY_EU = '102-01-031-20 W4 - CTY EU Horizon 2020 BRAINTIME'
    N_102_01_031_20_W5_CTY_EU = '102-01-031-20 W5 - CTY EU Horizon 2020 BRAINTIME'
    N_102_01_032_20_CTY_MOUS = '102-01-032-20 CTY Mouse Aging'
    N_102_01_036_20_CTY_DISS = '102-01-036-20 CTY Dissemination of 3-Photon Imaging'
    N_102_01_040_20_CTY_BRAIN = '102-01-040-20 CTY BRAIN UG3/UH3 Genetic Viral Tools'
    N_102_01_043_20_CTY_OPTI = '102-01-043-20 CTY Optical interrogation'
    N_102_01_044_10_CTY_GENO = '102-01-044-10 – CTY Genomics'
    N_102_01_045_10_CTY_IVSCC = '102-01-045-10 – CTY IVSCC'
    N_102_01_046_20_CTY_WEIL = '102-01-046-20 - CTY Weill Neuronal Heterogeneity'
    N_102_01_048_10_CTY_BARC = '102-01-048-10 CTY Barcoded Connectomics'
    N_102_01_049_20_CTY_OPIO = '102-01-049-20 - CTY Opioid Transcriptomics'
    N_102_01_054_20_CTY_PFAC = '102-01-054-20 CTY PFAC'
    N_102_01_055_20_CTY_EM_M = '102-01-055-20 CTY EM Motor Cortex'
    N_102_01_059_20_CTY_SCORC = '102-01-059-20 CTY SCORCH'
    N_102_01_060_20_CTY_BRAI = '102-01-060-20 CTY Brain Drain'
    N_102_01_061_20_CTY_BICAN = '102-01-061-20 CTY BICAN Human and NHP Atlas'
    N_102_01_062_10_AIBS_BICA = '102-01-062-10 AIBS BICAN Mouse Developmental Atlas'
    N_102_01_064_10_CTY_GENE = '102-01-064-10 CTY Genetic Tools'
    N_102_01_066_20_AIBS_CTY = '102-01-066-20 AIBS CTY CONNECTS HIVE'
    N_102_01_066_20_AIND_CTY = '102-01-066-20 AIND CTY CONNECTS HIVE'
    N_102_01_068_20_CTY_CONNE = '102-01-068-20 CTY CONNECTS Patchlink'
    N_102_01_069_20_PRE_SPE = '102-01-069-20 Pre-Spend'
    N_102_01_070_20_CTY_CONNE = '102-01-070-20 CTY CONNECTS MouseConnects'
    N_102_01_073_20_CTY_CT_P = '102-01-073-20 CTY CT Projectome'
    N_102_01_078_20_AIBS_VOC = '102-01-078-20 AIBS Vocal Circuit'
    N_102_01_079_20_AIBS_CONN = '102-01-079-20 AIBS CONNECTS TransNeuronal Tools'
    N_102_01_083_20_AIBS_WB_A = '102-01-083-20 AIBS WB AAV Toolbox'
    N_102_01_999_10_CTY_PROG = '102-01-999-10 CTY Program Admin'
    N_102_02_004_10_BTV_VISU = '102-02-004-10 BTV Visual Behavior'
    N_102_02_012_20_BTV_BRAIN = '102-02-012-20 BTV BRAIN Viral Strategies'
    N_102_04_004_10_OTH_MERI = '102-04-004-10 OTH Meritorious Scholar Directed Research'
    N_102_04_006_20_OTH_MEAS = '102-04-006-20 OTH Measuring Consciousness Ph2 (TBD)'
    N_102_04_007_10_APLD_TAR = '102-04-007-10 APLD Targeted CNS Gene Therapy'
    N_102_04_011_10_CTY_SR_SY = '102-04-011-10 CTY SR: SYNGAP1'
    N_102_04_012_10_CTY_SR_F = '102-04-012-10 : CTY SR: Friedreich Ataxia'
    N_102_04_016_20_CTY_DRAV = '102-04-016-20 CTY Dravet Phase 3 WRF'
    N_102_04_017_10_AIBS_EPI = '102-04-017-10 AIBS Epilepsy'
    N_102_04_019_20_AIBS_DSF = '102-04-019-20 AIBS DSF Dravet'
    N_102_88_001_10_XPG_CORE = '102-88-001-10 XPG Core Imaging: BARseq'
    N_102_88_001_10_XPG_CORE_2 = '102-88-001-10 XPG Core Imaging: Methods Development'
    N_122_88_002_10_XPG_CORE = '122-88-002-10 XPG Core NSB Behavior'
    N_102_88_003_10_ANIMAL = '102-88-003-10 Animal Care Team'
    N_102_88_005_10_TRANSGEN = '102-88-005-10 Transgenic Colony Management'
    N_102_88_008_10_LAB_ANI = '102-88-008-10 Lab Animal Services'
    N_106_09_001_10_TISSUE = '106-09-001-10 Tissue Immunity'
    N_110_01_001_10_PG_PROTE = '110-01-001-10 PG Proteomics'
    N_121_01_016_20_MSP_BRAIN = '121-01-016-20 MSP BRAIN OpenScope'
    N_121_01_018_20_MSP_EPHA = '121-01-018-20 MSP Ephaptic Cell Typ'
    N_121_01_023_20_MSP_TEMP = '121-01-023-20 MSP Templeton - Testing Theories of Consciousness'
    N_121_01_025_20_MSP_U01 = '121-01-025-20 MSP U01 Bridging Function, Connectivity, & Transcriptomics'
    N_121_01_026_20_MSP_TEMP = '121-01-026-20 MSP Templeton Measuring Distinct Conscious State'
    N_122_01_001_10_AIND_SCI = '122-01-001-10 AIND Scientific Activities'
    N_122_01_002_20_MOLECULA = '122-01-002-20 Molecular Core'
    N_122_01_004_20_AIND_BRA = '122-01-004-20 AIND Brainstem RF1'
    N_122_01_010_20_AIND_POO = '122-01-010-20 - AIND Poo Simons BTI'
    N_122_01_011_20_AIND_COH = '122-01-011-20 - AIND Cohen JHU R01 Transferred Subaward'
    N_122_01_012_20_AIND_RF1 = '122-01-012-20 - AIND RF1 Functions of locus coeruleus'
    N_122_01_013_10_MSP_SCIE = '122-01-013-10 MSP Scientific Activities'
    N_122_01_014_20_AIND_SIE = '122-01-014-20 - AIND Siegle U01 NPOpto'
    N_122_01_019_20_AIND_CZI = '122-01-019-20 AIND CZI Collaborative Pairs'
    N_122_01_020_20_AIBS_COH = '122-01-020-20 AIBS Cohen BICAN R01'
    N_122_01_020_20_AIND_COH = '122-01-020-20 AIND Cohen BICAN R01'
    N_122_01_022_20_AIND_POD = '122-01-022-20 AIND Podgorski UM1'
    N_123_01_003_20_MOTOR_C = '123-01-003-20 Motor Circuit Dysfunction in PD'
    N_124_01_001_10_BRAIN_C = '124-01-001-10 Brain & Consciousness (Direct)'
    N_125_01_001_10_SEA_HUB = '125-01-001-10 - SeaHub Scientific Activities (Direct)'
    N_127_01_001_10_CELL_CI = '127-01-001-10 Cell & Circuit Therapeutics'
    AAV_PRODUCTION_102_88_004 = 'AAV production 102-88-004-10'
    R_D_102_88_004_10 = 'R&D 102-88-004-10'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LASProjectid from a JSON string"""
        return cls(json.loads(json_str))


