# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2019IacucProtocol(str, Enum):
    """
    Enum class for IacucProtocol
    """

    """
    allowed enum values
    """
    N_2001 = '2001'
    N_2002 = '2002'
    N_2003 = '2003'
    N_2004 = '2004'
    N_2005 = '2005'
    N_2006 = '2006'
    N_2011 = '2011'
    N_2102 = '2102'
    N_2103 = '2103'
    N_2104 = '2104'
    N_2105 = '2105'
    N_2106 = '2106'
    N_2107 = '2107'
    N_2108 = '2108'
    N_2109 = '2109'
    N_2110 = '2110'
    N_2113 = '2113'
    N_2115 = '2115'
    N_2117 = '2117'
    N_2201 = '2201'
    N_2202 = '2202'
    N_2205 = '2205'
    N_2212 = '2212'
    SELECT = 'Select...'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2019IacucProtocol from a JSON string"""
        return cls(json.loads(json_str))


