# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LASLimsworkflow(str, Enum):
    """
    Enum class for LIMSWorkflow.
    """

    """
    allowed enum values
    """
    N_2P_SERIAL_IMAGING = '2p serial Imaging'
    T601_1_RETINA = 'T601.1 Retina'
    T601_2A_RETROGRADE_CAV2 = 'T601.2a Retrograde CAV2-Cre;Ai75'
    T601_2B_RETROGRADE_RABI = 'T601.2b Retrograde Rabies-GFP'
    T601_2C_RETROGRADE_FLUO = 'T601.2c Retrograde Fluorogold'
    T601_3A_ANTEROGRADE_CRE = 'T601.3a Anterograde Cre-Defined EGFP'
    T601_3B_ANTEROGRADE_CRE = 'T601.3b Anterograde Cre-Deflned SypEGFP'
    T601_4_ANTEROGRADE_TARG = 'T601.4 Anterograde Target Defined'
    T601_5_TRANS_SYNAPTIC = 'T601.5 trans-synaptic'
    SCREENING = 'Screening'
    CHARACTERIZATION = 'Characterization'
    T503_2_ANTEROGRADE_TARG = 'T503.2 Anterograde Target-Defined'
    T503_3_ALZHEIMER_S_PLAQ = 'T503.3 Alzheimer\'s Plaque'
    T503_3_CONTROL = 'T503.3 control'
    T503_ANTEROGRADE_CRE_DEF = 'T503 anterograde Cre-defined SypEGFP'
    MGT_ANTEROGRADE_PROJECT = 'MGT Anterograde Projection Mapping'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LASLimsworkflow from a JSON string"""
        return cls(json.loads(json_str))


