# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023LimsTaskflow(str, Enum):
    """
    Enum class for LIMSTaskflow.
    """

    """
    allowed enum values
    """
    AIND_EPHYS_SURGERY_ONLY = 'AIND Ephys (Surgery only)'
    AIND_EPHYS_PASSIVE_BEHAVIOR = 'AIND Ephys (Passive Behavior)'
    AIND_U19_AAV_RETROGRADE = 'AIND U19 AAV Retrograde'
    AIND_U19_RAB_V_RETROGRADE = 'AIND U19 RabV Retrograde'
    AIND_U19_THALAMUS = 'AIND U19 Thalamus'
    AIND_WATERLOG = 'AIND Waterlog'
    BRAIN_LARGE_SCALE_RECORDING = 'BRAIN Large Scale Recording'
    BRAIN_MOUSE_BRAIN_CELL_ATLAS_TRANS_SYNAPTIC = 'BRAIN Mouse Brain Cell Atlas trans-synaptic'
    BRAIN_OBSERVATORY_DEEPSCOPE = 'Brain Observatory Deepscope'
    BRAIN_OBSERVATORY_EPHYS_DEV = 'Brain Observatory Ephys Dev'
    BRAIN_OBSERVATORY_MAPSCOPE = 'Brain Observatory Mapscope'
    BRAIN_OBSERVATORY_MESOSCOPE = 'Brain Observatory Mesoscope'
    BRAIN_OBSERVATORY_MESOSCOPE_1G = 'Brain Observatory Mesoscope 1G'
    BRAIN_OBSERVATORY_NEUROPIXEL_DEV = 'Brain Observatory Neuropixel Dev'
    BRAIN_OBSERVATORY_TRANSGENIC_CHARACTERIZATION = 'Brain Observatory Transgenic Characterization'
    BRAIN_OBSERVATORY_V1_DD = 'Brain Observatory V1DD'
    BRAIN_OBSERVATORY_VISUAL_BEHAVIOR = 'Brain Observatory Visual Behavior'
    BRAIN_OBSERVATORY_VISUAL_BEHAVIOR_1B = 'Brain Observatory Visual Behavior 1B'
    BRAIN_OBSERVATORY_VISUAL_BEHAVIOR_NEUROPIXEL = 'Brain Observatory Visual Behavior Neuropixel'
    BRAIN_OBSERVATORY_VISUAL_CODING = 'Brain Observatory Visual Coding'
    BTV_BRAIN_VIRAL_STRATEGIES = 'BTV BRAIN Viral Strategies'
    CITRIC_ACID_PILOT = 'Citric Acid Pilot'
    EPHYS_DEV_VISUAL_BEHAVIOR = 'Ephys Dev Visual Behavior'
    EPHYS_DEV_VISUAL_BEHAVIOR_2 = 'Ephys Dev Visual Behavior 2'
    EPHYS_TASK_DEV_DYNAMIC_ROUTING_DOC_LEFT_EYE = 'Ephys Task Dev Dynamic Routing DOC Left Eye'
    EPHYS_TASK_DEV_DYANMIC_ROUTING_NSB_BEH = 'Ephys Task Dev Dyanmic Routing (NSB Beh)'
    EPHYS_TASK_DEV_DYNAMIC_ROUTING_SC_BEH = 'Ephys Task Dev Dynamic Routing (S/C Beh)'
    IVSCC_HVA_RETRO_PATCHSEQ = 'IVSCC HVA Retro PatchSeq'
    IVSCCM_INJECTION = 'IVSCCm injection'
    IVSPCM_INJECTION = 'IVSPCm Injection'
    MGT_LAB = 'MGT Lab'
    MGT_TISSUECYTE = 'MGT TissueCyte'
    MINDSCOPE_2P_TESTING = 'Mindscope 2P Testing'
    MSP_DYNAMIC_ROUTING_BEHAVIOR_DEVELOPMENT = 'MSP Dynamic Routing Behavior Development'
    MSP_DYNAMIC_ROUTING_OPTO_DEV = 'MSP Dynamic Routing Opto Dev'
    MSP_DYNAMIC_ROUTING_SURGICAL_DEVELOPMENT = 'MSP Dynamic Routing Surgical Development'
    MSP_DYNAMIC_ROUTING_ULTRA_OPTOTAGGING_BEHAVIOR = 'MSP Dynamic Routing Ultra Optotagging Behavior'
    MSP_DYNAMIC_ROUTING_TASK_1_PRODUCTION = 'MSP Dynamic Routing Task 1 Production'
    MSP_DYNAMIC_ROUTING_TASK_2_PRODUCTION = 'MSP Dynamic Routing Task 2 Production'
    MSP_GCAMP8_TESTING = 'MSP GCaMP8 Testing'
    MSP_GCAMP8_TESTING_RO = 'MSP GCaMP8 Testing (RO)'
    MSP_LEARNING_MFISH_DEVELOPMENT = 'MSP Learning & mFISH Development'
    MSP_LEARNING_MFISH_DEVELOPMENT_DOX = 'MSP Learning & mFISH Development (Dox)'
    MSP_LEARNING_MFISH_FRONTAL_WINDOW_DEV = 'MSP Learning & mFISH Frontal Window Dev'
    MSP_LEARNING_MFISH_VIRUS_TESTING = 'MSP Learning & mFISH Virus Testing'
    MSP_OMFISH_COREGISTRATION_PILOT = 'MSP omFISH Co-registration Pilot'
    MSP_OMFISH_CUX2_PILOT = 'MSP omFISH Cux2 Pilot'
    MSP_OMFISH_GAD2_MESO = 'MSP omFISH Gad2 Meso'
    MSP_OMFISH_GAD2_PILOT = 'MSP omFISH Gad2 Pilot'
    MSP_OMFISH_RBP4_MESO = 'MSP omFISH Rbp4 Meso'
    MSP_OMFISH_RORB_PILOT = 'MSP omFISH Rorb Pilot'
    MSP_OMFISH_ROB_INJECTION_VIRUS_PILOT = 'MSP omFISH ROB Injection Virus Pilot'
    MSP_OMFISH_SST_MESO_GAMMASTIM = 'MSP omFISH Sst Meso (GammaStim)'
    MSP_OMFISH_VIP_MESO_GAMMASTIM = 'MSP omFISH Vip Meso (GammaStim)'
    MSP_OPENSCOPE_DENDRITE_COUPLING = 'MSP OpenScope Dendrite Coupling'
    MSP_OPENSCOPE_ILLUSION = 'MSP OpenScope Illusion'
    MSP_OPENSCOPE_GLOBAL_LOCAL_ODDBALLS_COHORT_1 = 'MSP OpenScope Global Local Oddballs (Cohort 1)'
    MSP_OPENSCOPE_GLOBAL_LOCAL_ODDBALLS_COHORT_2 = 'MSP OpenScope Global Local Oddballs (Cohort 2)'
    MSP_TASK_TRAINED_NETWORKS_MULTISCOPE = 'MSP Task Trained Networks Multiscope'
    MSP_TASK_TRAINED_NETWORKS_NEUROPIXEL = 'MSP Task Trained Networks Neuropixel'
    MSP_U01_BRIDGING_FUNCTION_CONNECTIVITY_TRANSCRIPTOMICS = 'MSP U01 Bridging Function, Connectivity, and Transcriptomics'
    MSP_VARIABILITY_AIM_1 = 'MSP Variability Aim 1'
    MSP_VARIABILITY_AIM_1_PILOT = 'MSP Variability Aim 1 Pilot'
    MSP_VARIABILITY_SPONTANEOUS = 'MSP Variability Spontaneous'
    MSP_VIP_AXONAL_V1 = 'MSP VIP Axonal V1'
    MSP_VIP_SOMATIC_V1 = 'MSP VIP Somatic V1'
    OPENSCOPE_GAMMA_PILOT = 'OpenScope Gamma Pilot'
    OPENSCOPE_GAMMA_PRODUCTION = 'OpenScope Gamma Production'
    OPENSCOPE_INJECTION_VOLUME_PILOT = 'OpenScope Injection Volume Pilot'
    OPENSCOPE_MOTION_PILOT = 'OpenScope Motion Pilot'
    OPENSCOPE_MULTIPLEX_PILOT_INJECTION = 'OpenScope Multiplex Pilot Inj'
    OPENSCOPE_MULTIPLEX_PILOT_NOINJECTION = 'OpenScope Multiplex Pilot Nolnj'
    OPENSCOPE_MULTIPLEX_PRODUCTION_NOINJECTION = 'OpenScope Multiplex Production NoInj'
    OPENSCOPE_MULTIPLEX_PRODUCTION = 'OpenScope Multiplex Production'
    OPENSCOPE_LOOP = 'OpenScope Loop'
    OPENSCOPE_MOTION_PRODUCTION = 'Openscope Motion Production'
    OPENSCOPE_PSYCODE = 'OpenScope Psycode'
    OPENSCOPE_SEQUENCE_LEARNING = 'OpenScope Sequence Learning'
    OPENSCOPE_TEMPORAL_BARCODE = 'OpenScope Temporal Barcode'
    OPENSCOPE_TEMPORAL_BARCODE_TESTING = 'OpenScope Temporal Barcode Testing'
    OPENSCOPE_TEXTURE_ACTIVE = 'OpenScope Texture (Active)'
    OPENSCOPE_TEXTURE_PASSIVE = 'OpenScope Texture (Passive)'
    OPENSCOPE_VIRUS_VALIDATION = 'Openscope Virus Validation'
    OPENSCOPE_VISION_2_HIPPOCAMPUS = 'OpenScope Vision 2 Hippocampus'
    OPENSCOPE_VISMO = 'OpenScope Vismo'
    OPENSCOPE_WHC_2P_DEV = 'OpenScope WHC 2P Dev'
    TEMPLETON_PSYCHEDELICS = 'Templeton Psychedelics'
    TILTY_MOUSE = 'Tilty Mouse'
    TINY_BLUE_DOT_BEHAVIOR = 'Tiny Blue Dot Behavior'
    TRANSGENIC_CHARACTERIZATION_PASSIVE = 'Transgenic Characterization (Passive)'
    VISB_DEV_CONTROL_GROUP = 'VisB Dev Control Group'
    VISB_LATERAL_PREP_DEVELOPMENT = 'VisB Lateral Prep Development'
    VISB_TASK_2_DEVELOPMENT = 'VisB Task 2 Development'
    VGT_ENHANCERS_TRANSSYNAPTIC = 'VGT Enhancers Transsynaptic'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023LimsTaskflow from a JSON string"""
        return cls(json.loads(json_str))


