# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023BehaviorType(str, Enum):
    """
    Enum class for NSB2023Behavior Type.
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    FORAGING = 'Foraging'
    FORAGING_FP = 'Foraging + FP'
    WR__HAB = 'WR+Hab'
    HAB__ONLY = 'Hab Only'
    AIBS_CHARACTERIZATION_ROT = 'AIBS Characterization (Rotarod & Open Field)'
    AIND_FORAGING_TASK_WITH_O = 'AIND Foraging Task (with or without fiber photometry)'
    AIND_MOTOR_OBSERVATORY_WH = 'AIND Motor Observatory (Wheel & Open Field & Isometric Task)'
    CHANGE_DETECTION_TASK = 'Change Detection Task'
    DR_AUDITORY_VISUAL_TASK = 'DR Auditory/Visual Task'
    HABITUATION_ONLY = 'Habituation Only'
    HABITUATION_PASSIVE_TRAIN = 'Habituation + Passive Training'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023BehaviorType from a JSON string"""
        return cls(json.loads(json_str))


