# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2019HeadpostType(str, Enum):
    """
    Enum class for HeadpostType
    """

    """
    allowed enum values
    """
    AI_STRAIGHT_HEADBAR = 'AI Straight Headbar'
    CAMSTYLE_HEADFRAME_016010 = 'CAM-style headframe (0160-100-10 Rev A)'
    MESOSCOPESTYLE_WELL_WITH = 'Mesoscope-style well with NGC-style headframe (0160-200-20/0160-100-10)'
    NEUROPIXELSTYLE_HEADFRAME = 'Neuropixel-style headframe (0160-100-10/0160-200-36)'
    NGCSTYLE_HEADFRAME_NO_WEL = 'NGC-style headframe, no well (0160-100-10)'
    SELECT = 'Select...'
    WHC_42_WITH_NEUROPIXEL_WE = 'WHC #42 with Neuropixel well and well cap'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2019HeadpostType from a JSON string"""
        return cls(json.loads(json_str))


