# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LASProtocol(str, Enum):
    """
    Enum class for Protocol.
    """

    """
    allowed enum values
    """
    N_2207_IN_VITRO_BRAIN = '2207 - In Vitro Brain Stimulation'
    N_2212_INVESTIGATING_BR = '2212 - Investigating Brain States'
    N_2301_TESTING_OF_ENHANC = '2301 - Testing of enhancers and AAV gene therapy vectors'
    N_2304_NEUROSURGERY_BEH = '2304 - Neurosurgery & Behavior Training Protocol'
    N_2305_IN_VIVO_BRAIN = '2305 - In Vivo Brain Stimulation'
    N_2306_PATCH_SEQ_CHARACT = '2306 - Patch-seq characterization of mouse neurons in acute brain slices for cross-species comparison studies'
    N_2307_DISSECTING_THE_NE = '2307 - Dissecting the neural circuits of adaptive control of behavior'
    N_2308_INDUCTION_OF_IMM = '2308 - Induction of Immune Memory'
    N_2401_THE_USE_OF_MICE_F = '2401 - The use of mice for the development of biological recorders'
    N_2402_BRAIN_OBSERVATOR = '2402 - Brain Observatory Optical Physiology'
    N_2403_ELECTROPHYSIOLOGY = '2403 - Electrophysiology Mindscope Phase 4'
    N_2405_ANALYSIS_OF_INTE = '2405 - Analysis of Integrated Neuronal Phenotypes'
    N_2406_CHARACTERIZATION = '2406 - Characterization of mouse and viral genetic tools'
    N_2410_VALIDATION_OF_BRA = '2410 - Validation of brain cell type enhancer AAV vectors in rats'
    N_2412_CIRCUIT_TRACING_A = '2412 - Circuit tracing and optical physiology of mouse cortex'
    N_2413_NEUROPHYSIOLOGY_O = '2413 - Neurophysiology of Naturalistic Learning'
    N_2414_ELECTROPHYSIOLOGI = '2414 - Electrophysiological and optical interrogation of brain-wide neural circuits in the mouse'
    N_2415_OPTOPHYSIOLOGICAL = '2415 - Optophysiological analysis of brain-wide neural circuits in the mouse'
    N_2416_ANATOMICAL_ANALYS = '2416 - Anatomical analysis of brain-wide neural circuits in the mouse'
    N_2417_CHARACTERIZATION = '2417 - Characterization of transcriptomic cell type activation and their molecular adaptations that occur during psychedelic, antidepressants, and antipsychotic drug use'
    N_2418_IN_VITRO_SINGLE = '2418 - In Vitro Single Cell Characterization'
    N_2427_OPEN_SCOPE_MINDS = '2427 - OpenScope Mindscope animal protocol for Optical Physiology and Neuropixel'
    N_2453_MOUSE_BREEDING = '2453 - Mouse Breeding'
    N_2457_TRAINING_AND_QUAL = '2457 - Training and qualification of animal users'
    N_2459_SPATIAL_CONNECTOM = '2459 - Spatial, connectomic and molecular characterization of spinal cord and sympathetic nervous system'
    N_2505_TESTING_AA_VS_IN = '2505 - Testing AAVs in Parkinson\'s mouse models'
    N_2511_DISSECTING_THE_NE = '2511 - Dissecting the neural circuits of motor learning and control'
    N_2530_DEVELOPMENT_OF_T = '2530 - Development of Transgenic Technologies & Methodologies'
    N_2538_INTERROGATING_PRO = '2538 - Interrogating projections and gene expression of neurons by in situ sequencing'
    N_2547_PROTEOMIC_EXPLORA = '2547 - Proteomic exploration of cell types'
    N_2577_IN_VITRO_BRAIN = '2577 - In Vitro Brain Stimulation'
    N_2580_OPTIMIZATION_AND = '2580 - Optimization and validation of viral vectors'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LASProtocol from a JSON string"""
        return cls(json.loads(json_str))


