# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023ImplantIdCoverslipType(str, Enum):
    """
    Enum class for Implant ID/Coverslip type.
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    N_2002 = '2002'
    N_2005 = '2005'
    N_2006 = '2006'
    N_2011 = '2011'
    N_2013 = '2013'
    N_2014 = '2014'
    N_2015 = '2015'
    N_3003 = '3003'
    N_3004 = '3004'
    N_3004_25_PURALUBE_SYSTAN = '3004 (25% puralube/systane)'
    N_3005 = '3005'
    N_3006 = '3006'
    N_3007 = '3007'
    N_3008 = '3008'
    WHC_2_P_CURVED_GLASS_WITH = 'WHC 2P curved glass (with window frame)'
    N_3MM_STACKED_COVERSLIP = '3mm stacked coverslip'
    N_5MM_STACKED_COVERSLIP = '5mm stacked coverslip'
    N_5MM_STACKED_COVERSLIP_W = '5mm stacked coverslip (with silicone coating for Neuropixel)'
    N_2001 = '2001'
    N_2004 = '2004'
    N_2010 = '2010'
    N_3001 = '3001'
    N_2007 = '2007'
    N_2008 = '2008'
    N_2009 = '2009'
    N_3002 = '3002'
    N_3002_25_PURALUBESYSTANE = '3002 (25% puralube/systane)'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023ImplantIdCoverslipType from a JSON string"""
        return cls(json.loads(json_str))


