# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LASPostfix(str, Enum):
    """
    Enum class for PostFix.
    """

    """
    allowed enum values
    """
    N_30_SUCROSE = '30% Sucrose'
    N_30_SUCROSE_FOIL_WRAPPE = '30% Sucrose (foil-wrapped tube)'
    N_1X_PBS = '1xPBS'
    N_1X_PBS_FOIL_WRAPPED_TUB = '1xPBS (foil-wrapped tube)'
    N_1X_PBS_0_01_AZIDE = '1xPBS+ 0.01%Azide'
    N_1X_PBS_0_01_AZIDE_5M_L = '1xPBS+ 0.01%Azide (5mL tubes)'
    N_1X_PBS_0_01_AZIDE_FOIL = '1xPBS+ 0.01%Azide (foil-wrapped tube)'
    N_4_PFA_TO_1X_PBS = '4%PFA to 1xPBS'
    NUCLEASE_FREE_1X_PBS_OM_F = 'Nuclease-free 1xPBS (omFISH)'
    NUCLEASE_FREE_30_SUCROSE = 'Nuclease-free 30% Sucrose'
    NUCLEASE_FREE_30_SUCROSE_2 = 'Nuclease-free 30% Sucrose(FOIL)'
    DPBS_NUCLEASE_FREE = 'DPBS(Nuclease-free)'
    OTHER_SPECIFY_BELOW = 'Other (Specify below)'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LASPostfix from a JSON string"""
        return cls(json.loads(json_str))


