# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2019ImplantIdCoverslipType(str, Enum):
    """
    Enum class for ImplantIdCoverslipType
    """

    """
    allowed enum values
    """
    CUSTOM_IMPLANT_ADD_DETAIL = 'Custom Implant (add details in comments section)'
    N_2001 = '2001'
    N_2002 = '2002'
    N_3001 = '3001'
    N_5MM_STACKED_COVERSLIP = '5mm stacked coverslip'
    N_5MM_STACKED_COVERSLIP_W = '5mm stacked coverslip (with silicone coating for Neuropixel)'
    SELECT = 'Select...'
    TS_04 = 'TS-04'
    TS_05 = 'TS-05'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2019ImplantIdCoverslipType from a JSON string"""
        return cls(json.loads(json_str))


