# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023Burr5VirusBiosafteyLevelBsl(str, Enum):
    """
    Enum class for Burr5 Virus Biosaftey Level (BSL).
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    BSL_1_AAV = 'BSL 1 - AAV'
    BSL_1__BEADS = 'BSL 1 - Beads'
    BSL_1_AAV__BEADS = 'BSL 1 - AAV + Beads'
    BSL_1__OTHER__WRITE_IN_CO = 'BSL 1 - Other (Write in comments)'
    BSL_2__RABIES = 'BSL 2 - Rabies'
    BSL_2_CAV = 'BSL 2 - CAV'
    BSL_2_6_OHDA = 'BSL 2 - 6-OHDA'
    BSL_2__SINDBIS = 'BSL 2 - Sindbis'
    BSL_2_HSV_1 = 'BSL 2 - HSV-1'
    BSL_2__LENTI = 'BSL 2 - Lenti'
    BSL_2__CHOLERA__TOXIN_B = 'BSL 2 - Cholera Toxin B'
    BSL_2__OTHER__WRITE_IN_CO = 'BSL 2 - Other (Write in comments)'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023Burr5VirusBiosafteyLevelBsl from a JSON string"""
        return cls(json.loads(json_str))


