# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023Headpost(str, Enum):
    """
    Enum class for NSB2023Headpost.
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    AI_STRAIGHT_BAR = 'AI Straight bar'
    FRONTAL_CTX = 'Frontal Ctx'
    LSHAPED = 'L-shaped'
    MOTOR_CTX = 'Motor Ctx'
    VISUAL_CTX = 'Visual Ctx'
    WHC_FULL_RING = 'WHC (Full ring)'
    WHC_NP_ZIRCONIA = 'WHC NP (Zirconia)'
    WHC_NP = 'WHC NP'
    WHC_2P = 'WHC 2P'
    LC = 'LC'
    DHC = 'DHC'
    OTHER_ADD_DETAILS_IN_REQU = 'Other (add details in requestor comments)'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023Headpost from a JSON string"""
        return cls(json.loads(json_str))


